BitPacker

Struct BitPacker 

pub struct BitPacker {
    pub output: Vec<u8>,
    pub padding: u8,
    /* private fields */
}
Creates a huffman-encoded, packed bitstream of one block of data. The final byte of the block is padded with zeros to reach a full byte. The padding is always a number between 0 and 7 inclusive.

Fields

output: Vec<u8>

The output buffer which can be read externally.

padding: u8

The number of zero bits padded to the last byte of the output buffer.

Implementations

Source

impl BitPacker

Creates a huffman-encoded, packed bitstream of one block of data. The final byte of the block is padded with zeros to reach a full byte. The padding is always a number between 0 and 7 inclusive.

pub fn new(size: usize) -> Self

Create a new BitPacker with an output buffer with the capacity specified in size.

pub fn out24(&mut self, data: u32)

Writes 0-24 bits encoded with the number of bits to write in the most significant byte of a 32 bit word.

pub fn out32(&mut self, data: u32)

Puts a 32 bit word of pre-packed binary encoded data on the stream.

pub fn out16(&mut self, data: u16)

Puts a 16 bit word of pre-packed binary encoded data on the stream.

pub fn flush(&mut self)

Flushes the remaining bits (1-7) from the buffer, padding with 0s in the least signficant bits. Flush MUST be called before reading the output or data may be left in the private queue.

pub fn loc(&self) -> String

Debugging function to return the number of bytes.bits output so far