pub struct Node {
pub weight: u32,
pub depth: u8,
pub syms: u32,
pub node_data: NodeData,
}Expand description
Huffman codes are built from weights derived from a tree structure of these nodes.
Fields
weight: u32The weight of the node is based on the frequency of the symbols under this node
depth: u8The depth of the node in the tree
syms: u32node_data: NodeDataThe data associated with this node (either a leaf or a node that (eventually) has leaves)
Implementations