Parse the command line for Rust BZIP2.
The options that can be set are defined in the BzOpts struct. An instance of the struct must be created and
initialized.
Usage example:
let mut opts = BzOpts::new();
opts.init();You can then access the options via the instance you created.
Structs
Enums
- Mode
- Zip, Unzip, Test, and testing out Build_Index and Unzip_Blocks
- Output
- Define the two output channels
- Status
- NOT YET IMPLEMENTED. Used during the library mode by the calling program.
- Verbosity
- Verbosity of user information
Functions
- bzopts_
init - Initialize the options struct by parsing data supplied via the command line. Takes no arguments and returns nothing.