BzOpts

Struct BzOpts 

pub struct BzOpts {
    pub block_size: usize,
    pub files: Vec<String>,
    pub force_overwrite: bool,
    pub keep_input_files: bool,
    pub iterations: usize,
    pub op_mode: Mode,
    pub output: Output,
    pub small: bool,
    pub status: Status,
    pub verbose: Verbosity,
    pub work_factor: usize,
}

Fields

block_size: usize

Maximum input block size to process during each loop

files: Vec<String>

Vec of names of files to read for input

force_overwrite: bool

Silently overwrite existing files with the same name

keep_input_files: bool

Don’t remove input files after processing

iterations: usize

Iterations used to test/optimize small block compression

op_mode: Mode

Compress/Decompress/Test

output: Output

Location where output is sent

small: bool

Small memory footprint requested

status: Status

Current status of progress - not yet used

verbose: Verbosity

Verbosity of user information

work_factor: usize

Optional setting used for oddly constructed data - may be depricated

Implementations

Source

impl BzOpts

pub fn new() -> Self