pub struct BzOpts {
pub block_size: usize,
pub files: Vec<String>,
pub force_overwrite: bool,
pub keep_input_files: bool,
pub iterations: usize,
pub op_mode: Mode,
pub output: Output,
pub small: bool,
pub status: Status,
pub verbose: Verbosity,
pub work_factor: usize,
}Fields
block_size: usizeMaximum input block size to process during each loop
files: Vec<String>Vec of names of files to read for input
force_overwrite: boolSilently overwrite existing files with the same name
keep_input_files: boolDon’t remove input files after processing
iterations: usizeIterations used to test/optimize small block compression
op_mode: ModeCompress/Decompress/Test
output: OutputLocation where output is sent
small: boolSmall memory footprint requested
status: StatusCurrent status of progress - not yet used
verbose: VerbosityVerbosity of user information
work_factor: usizeOptional setting used for oddly constructed data - may be depricated
Implementations